Module stream

Module stream 

Available on crate feature stream only.
Adapt a Stream into an event source

Only available with the stream cargo feature of calloop.

The stream will be polled by the event loop, allowing the event source’s callback to handle each event from the stream. This allows streams that are woken by events in a different thread to be naturally integrated into a calloop event loop.

Structs

StreamError
An error arising from processing events for a stream.
StreamSource
Stream-based event source.