Available on crate feature
stream only.Expand description
Adapt a Stream into an event source
Only available with the stream cargo feature of calloop.
The stream will be polled by the event loop, allowing the event source’s
callback to handle each event from the stream. This allows streams that
are woken by events in a different thread to be naturally integrated into
a calloop event loop.
Structs
- Stream
Error - An error arising from processing events for a stream.
- Stream
Source Stream-based event source.